@@ -29,6 +29,8 @@ class EssbasicClient(AbstractClient):
     def ChannelBatchCancelFlows(self, request):
         """指定需要批量撤销的签署流程Id，批量撤销合同
         客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口失败后返回错误信息
+        注意:
+        能撤回合同的只能是合同的发起人或者发起企业的超管、法人
 
         :param request: Request instance for ChannelBatchCancelFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelBatchCancelFlowsRequest`
@@ -87,7 +89,10 @@ class EssbasicClient(AbstractClient):
 
     def ChannelCreateBatchCancelFlowUrl(self, request):
         """指定需要批量撤销的签署流程Id，获取批量撤销链接
-        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销
+        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
+        接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销;
+        注意:
+        能撤回合同的只能是合同的发起人或者发起企业的超管、法人
 
         :param request: Request instance for ChannelCreateBatchCancelFlowUrl.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlRequest`
@@ -145,7 +150,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateFlowByFiles(self, request):
-        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口不可直接使用，需要运营申请
+        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口静默签能力不可直接使用，需要运营申请
 
         :param request: Request instance for ChannelCreateFlowByFiles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesRequest`
@@ -293,6 +298,35 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelVerifyPdf(self, request):
+        """合同文件验签
+
+        :param request: Request instance for ChannelVerifyPdf.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelVerifyPdfRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelVerifyPdfResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelVerifyPdf", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelVerifyPdfResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateChannelFlowEvidenceReport(self, request):
         """【描述】：创建出证报告，返回报告 URL
         【注意】：此接口需要通过添加白名单获取调用权限，请联系运营人员加白
@@ -324,7 +358,10 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateConsoleLoginUrl(self, request):
-        """此接口（CreateConsoleLoginUrl）用于创建电子签控制台登录链接。若企业未激活，调用同步企业信息、同步经办人信息
+        """此接口（CreateConsoleLoginUrl）用于创建渠道子客企业控制台Web端登录链接。Web端登录链接是子客控制台的唯一入口。
+        若子客企业未激活，会进入企业激活流程,首次参与激活流程的经办人会成为超管。（若企业激活过程中填写信息有误，需要重置激活流程，可以换一个经办人OpenId获取新的链接进入。）
+        若子客企业已激活，使用了新的经办人OpenId进入，则会进入经办人的实名流程。
+        若子客企业、经办人均已完成认证，则会直接进入子客Web控制台。
 
         :param request: Request instance for CreateConsoleLoginUrl.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateConsoleLoginUrlRequest`
@@ -651,7 +688,7 @@ class EssbasicClient(AbstractClient):
 
 
     def SyncProxyOrganization(self, request):
-        """此接口（SyncProxyOrganization）用于同步渠道侧企业信息
+        """此接口（SyncProxyOrganization）用于同步渠道子客企业信息，主要是子客企业的营业执照，便于子客企业开通过程中不用手动上传。若有需要调用此接口，需要在创建控制链接CreateConsoleLoginUrl之后即刻进行调用。
 
         :param request: Request instance for SyncProxyOrganization.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationRequest`
@@ -680,7 +717,8 @@ class EssbasicClient(AbstractClient):
 
 
     def SyncProxyOrganizationOperators(self, request):
-        """此接口（SyncProxyOrganizationOperators）用于同步渠道合作企业经办人列表
+        """此接口（SyncProxyOrganizationOperators）用于同步渠道子客企业经办人列表，主要是同步经办人的离职状态。子客Web控制台的组织架构管理，是依赖于渠道平台的，无法针对员工做新增/更新/离职等操作。
+        若经办人信息有误，或者需要修改，也可以先将之前的经办人做离职操作，然后重新使用控制台链接CreateConsoleLoginUrl让经办人重新实名。
 
         :param request: Request instance for SyncProxyOrganizationOperators.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationOperatorsRequest`
